
-- ----------------------------
-- Table structure for tbl_accountinfo
-- ----------------------------
DROP TABLE IF EXISTS `tbl_accountinfo`;
CREATE TABLE `tbl_accountinfo` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '账号id',
  `account` varchar(255) DEFAULT NULL COMMENT '账号',
  `password` varchar(255) DEFAULT NULL COMMENT '密码',
  `nickname` varchar(255) DEFAULT NULL COMMENT '昵称（中文显示名）',
  `type` varchar(255) DEFAULT NULL COMMENT '账号类型（-1:超级用户，0:管理员；1：操作员，可登录客户端，运营后台暂时没有权限）（类型后续可扩展）',
  `cid` int(11) DEFAULT NULL COMMENT '所属的客户id',
  `state` int(11) DEFAULT '1' COMMENT '当前账号状态1正常2禁用',
  `create_time` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`),
  UNIQUE KEY `account` (`account`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=15 DEFAULT CHARSET=utf8 COMMENT='账号表';

-- ----------------------------
-- Records of tbl_accountinfo
-- ----------------------------
INSERT INTO `tbl_accountinfo` VALUES ('1', 'root', '123456', 'admin', '-1', null, '1', '2019-03-11 09:49:24');
INSERT INTO `tbl_accountinfo` VALUES ('5', 'admin', '123456', 'admin', '0', '7', '1', '2019-03-11 09:49:24');
INSERT INTO `tbl_accountinfo` VALUES ('6', 'pctest', '123456', 'pctest', '1', '7', '1', '2019-03-11 09:49:22');

-- ----------------------------
-- Table structure for tbl_commontaginfo
-- ----------------------------
DROP TABLE IF EXISTS `tbl_commontaginfo`;
CREATE TABLE `tbl_commontaginfo` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `cid` int(11) DEFAULT NULL COMMENT '客户id',
  `name` varchar(255) COLLATE utf8mb4_bin DEFAULT NULL COMMENT '标签名称',
  `create_time` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=7 DEFAULT CHARSET=utf8mb4 COMMENT='标签表';

-- ----------------------------
-- Records of tbl_commontaginfo
-- ----------------------------
INSERT INTO `tbl_commontaginfo` VALUES ('5', '7', '潜在客户', '2019-03-07 17:40:18');
INSERT INTO `tbl_commontaginfo` VALUES ('6', '7', '想打他', '2019-03-14 17:54:30');

-- ----------------------------
-- Table structure for tbl_commonterminfo
-- ----------------------------
DROP TABLE IF EXISTS `tbl_commonterminfo`;
CREATE TABLE `tbl_commonterminfo` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `cid` int(11) DEFAULT NULL COMMENT '客户id',
  `tid` int(11) DEFAULT NULL COMMENT '术语分类id',
  `ctype` varchar(255) COLLATE utf8mb4_bin DEFAULT NULL COMMENT '类型',
  `name` varchar(255) COLLATE utf8mb4_bin DEFAULT NULL COMMENT '标题',
  `content` varchar(512) COLLATE utf8mb4_bin DEFAULT NULL COMMENT '内容',
  `create_time` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=23 DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin COMMENT='术语表';

-- ----------------------------
-- Records of tbl_commonterminfo
-- ----------------------------
INSERT INTO `tbl_commonterminfo` VALUES ('18', '7', '8', '1', '文字', 'SDK方案咨询请加微信happybabby110', '2021-11-26 10:35:13');
INSERT INTO `tbl_commonterminfo` VALUES ('20', '7', '8', '4', '语音文件', 'http://www.yunlauncher.com/files/weixin/amr.amr', '2021-11-26 10:30:36');
INSERT INTO `tbl_commonterminfo` VALUES ('21', '7', '8', '3', '视频文件', 'http://www.yunlauncher.com/files/weixin/mp4.mp4', '2021-11-26 10:30:41');
INSERT INTO `tbl_commonterminfo` VALUES ('22', '7', '8', '2', '图片', 'http://www.yunlauncher.com/files/weixin/tu.jpg', '2021-11-26 10:35:10');

-- ----------------------------
-- Table structure for tbl_commontermtype
-- ----------------------------
DROP TABLE IF EXISTS `tbl_commontermtype`;
CREATE TABLE `tbl_commontermtype` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `cid` int(11) DEFAULT NULL COMMENT '客户id',
  `name` varchar(255) COLLATE utf8mb4_bin DEFAULT NULL COMMENT '术语分类名称',
  `create_time` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=9 DEFAULT CHARSET=utf8mb4  COMMENT='术语分组表';

-- ----------------------------
-- Records of tbl_commontermtype
-- ----------------------------
INSERT INTO `tbl_commontermtype` VALUES ('8', '7', '常用语', '2020-09-01 11:52:05');

-- ----------------------------
-- Table structure for tbl_customerinfo
-- ----------------------------
DROP TABLE IF EXISTS `tbl_customerinfo`;
CREATE TABLE `tbl_customerinfo` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT 'SupplierId  UnionId,客户id',
  `suppliername` varchar(255) DEFAULT NULL COMMENT '客户名称（中文显示名）',
  `account_num` int(11) DEFAULT NULL COMMENT '最大账号（操作员）数量（依客户等级而定）',
  `device_num` int(11) DEFAULT NULL COMMENT '最大设备数量（依客户等级而定）',
  `validity` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP COMMENT '服务期限',
  `state` int(11) DEFAULT NULL COMMENT '当前客户状态',
  `admin` varchar(255) DEFAULT NULL COMMENT '管理员账号',
  `contact` varchar(255) DEFAULT NULL COMMENT '联系人姓名',
  `phone` varchar(255) DEFAULT NULL COMMENT '联系人电话',
  `description` varchar(255) DEFAULT NULL COMMENT '备注信息',
  `create_time` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=8 DEFAULT CHARSET=utf8 COMMENT='客户表';

-- ----------------------------
-- Records of tbl_customerinfo
-- ----------------------------
INSERT INTO `tbl_customerinfo` VALUES ('7', '售后客服部', '100', '1000', '2018-09-20 14:52:47', '1', 'admin', 'admin', '', '', '2018-09-20 14:52:47');

-- ----------------------------
-- Table structure for tbl_resources
-- ----------------------------
DROP TABLE IF EXISTS `tbl_resources`;
CREATE TABLE `tbl_resources` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `cid` int(11) DEFAULT NULL COMMENT '客户id',
  `type` varchar(512) DEFAULT NULL COMMENT '资源类型',
  `remarks` varchar(512) DEFAULT NULL COMMENT '备注',
  `content` text COMMENT '资源数据',
  `create_time` datetime DEFAULT NULL COMMENT '创建时间',
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=5 DEFAULT CHARSET=utf8mb4 COMMENT='素材资源库';


-- ----------------------------
-- Table structure for tbl_sys_autosettings
-- ----------------------------
DROP TABLE IF EXISTS `tbl_sys_autosettings`;
CREATE TABLE `tbl_sys_autosettings` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `cid` int(11) DEFAULT NULL,
  `state` int(11) DEFAULT NULL,
  `auto_type` int(11) DEFAULT NULL,
  `wechatid` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `create_time` timestamp NULL DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4  COMMENT='自动开关表';

-- ----------------------------
-- Records of tbl_sys_autosettings
-- ----------------------------

-- ----------------------------
-- Table structure for tbl_timetask
-- ----------------------------
DROP TABLE IF EXISTS `tbl_timetask`;
CREATE TABLE `tbl_timetask` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `accountid` int(11) DEFAULT NULL COMMENT '操作员id',
  `wechatid` varchar(255) DEFAULT NULL,
  `cid` int(11) DEFAULT NULL,
  `tasktype` int(11) DEFAULT NULL COMMENT '任务类型1群发消息2发朋友圈',
  `state` int(11) DEFAULT '1' COMMENT '状态1开启中0已完成',
  `execute_time` varchar(255) DEFAULT NULL COMMENT '执行时间',
  `restype` int(11) DEFAULT NULL COMMENT '资源类型',
  `content` text CHARACTER SET utf8mb4 COMMENT '文案内容',
  `comment` varchar(255) DEFAULT NULL COMMENT '评论',
  `remarks` varchar(1024) DEFAULT NULL COMMENT '备注',
  `update_time` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  `create_time` datetime DEFAULT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=8 DEFAULT CHARSET=utf8mb4 COMMENT='定时任务表';


-- ----------------------------
-- Table structure for tbl_timetask_details
-- ----------------------------
DROP TABLE IF EXISTS `tbl_timetask_details`;
CREATE TABLE `tbl_timetask_details` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `tid` int(11) DEFAULT NULL COMMENT '主任务id',
  `json_content` text CHARACTER SET utf8mb4  COMMENT '序列化的json字符串',
  `execute_time` varchar(255) COLLATE utf8mb4_unicode_ci DEFAULT NULL COMMENT '子任务执行时间',
  `state` int(11) DEFAULT '1' COMMENT '执行状态1未执行   0已执行',
  `results` varchar(2000) COLLATE utf8mb4_unicode_ci DEFAULT NULL,
  `create_time` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=10 DEFAULT CHARSET=utf8mb4 COMMENT='子任务表';


-- ----------------------------
-- Table structure for tbl_wx_accountinfo
-- ----------------------------
DROP TABLE IF EXISTS `tbl_wx_accountinfo`;
CREATE TABLE `tbl_wx_accountinfo` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `wxid` varchar(255) CHARACTER SET utf8 DEFAULT NULL COMMENT '微信id',
  `name` varchar(512) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci DEFAULT NULL COMMENT '微信昵称',
  `alias` varchar(512) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci DEFAULT NULL COMMENT '微信别称',
  `gender` int(11) DEFAULT NULL COMMENT '性别',
  `avatar` varchar(512) CHARACTER SET utf8 DEFAULT NULL COMMENT '头像url',
  `job` varchar(512) CHARACTER SET utf8 DEFAULT NULL COMMENT '职位',
  `phone` varchar(512) CHARACTER SET utf8 DEFAULT NULL COMMENT '电话号码',
  `corpid` varchar(512) CHARACTER SET utf8 DEFAULT NULL COMMENT '公司ID',
  `attr` varchar(512) CHARACTER SET utf8 DEFAULT NULL COMMENT '属性备用',
  `isonline` int(11) DEFAULT '1' COMMENT '是否在线   0上线   1下线',
  `deviceid` varchar(255) CHARACTER SET utf8 DEFAULT NULL COMMENT '微信登陆的设备',
  `cid` int(11) DEFAULT NULL COMMENT '客户id',
  `devnickname` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL COMMENT '设备昵称',
  `brand` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL COMMENT '手机品牌',
  `module` varchar(255) COLLATE utf8_unicode_ci DEFAULT NULL COMMENT '手机型号',
  `accountid` varchar(255) DEFAULT NULL COMMENT 'Pc客户端正在操作该微信的操作员账号id',
  `login_time` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  `modify_time` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  `create_time` datetime DEFAULT NULL COMMENT '创建时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `deviceid_wechatid` (`deviceid`,`wxid`) USING BTREE,
  UNIQUE KEY `deviceid` (`deviceid`) USING BTREE,
  UNIQUE KEY `wxid` (`wxid`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=172 DEFAULT CHARSET=utf8mb4 COMMENT='微信账号表';



-- ----------------------------
-- Table structure for tbl_wx_keywords
-- ----------------------------
DROP TABLE IF EXISTS `tbl_wx_keywords`;
CREATE TABLE `tbl_wx_keywords` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `cid` int(11) DEFAULT NULL COMMENT '客户id',
  `wechatid` varchar(255) DEFAULT NULL COMMENT '微信id',
  `key_type` int(4) DEFAULT '0' COMMENT '匹配类型 0精准完全匹配  1模糊包含匹配',
  `key_word` varchar(255) DEFAULT NULL COMMENT '关键词',
  `resource_type` int(4) COMMENT '资源类型 与消息类型一致',
  `return_string` varchar(5000) DEFAULT NULL COMMENT '回复词',
  `create_time` datetime DEFAULT NULL COMMENT '创建时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=10001 DEFAULT CHARSET=utf8mb4  COMMENT='关键词匹配';


-- ----------------------------
-- Table structure for tbl_sys_autosettings
-- ----------------------------
DROP TABLE IF EXISTS `tbl_sys_autosettings`;
CREATE TABLE `tbl_sys_autosettings` (
  `id` int(11) NOT NULL AUTO_INCREMENT,
  `cid` int(11) DEFAULT NULL,
  `state` int(11) DEFAULT NULL,
  `auto_type` int(11) DEFAULT NULL,
  `wechatid` varchar(255) DEFAULT NULL,
  `remarks` varchar(500) DEFAULT NULL COMMENT '备注',
  `create_time` timestamp NULL DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=58 DEFAULT CHARSET=utf8mb4  COMMENT='自动配置表';


-- ----------------------------
-- Table structure for tbl_wx_message
-- ----------------------------
DROP TABLE IF EXISTS `tbl_wx_message`;
CREATE TABLE `tbl_wx_message` (
  `id` int NOT NULL AUTO_INCREMENT,
  `cid` int DEFAULT NULL,
  `WxId` bigint DEFAULT NULL,
  `ConvId` bigint DEFAULT NULL,
  `SenderId` bigint DEFAULT NULL,
  `ContentType` varchar(255) DEFAULT NULL,
  `Content` text,
  `MsgId` bigint DEFAULT NULL,
  `MsgRemoteId` bigint DEFAULT NULL,
  `CreateTime` bigint DEFAULT NULL,
  `SenderName` varchar(255) DEFAULT NULL,
  `RefId` bigint DEFAULT NULL,
  `isSend` varchar(255) DEFAULT NULL,
  `create_time` datetime DEFAULT NULL ON UPDATE CURRENT_TIMESTAMP,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=3 DEFAULT CHARSET=utf8mb4  COMMENT='聊天消息表';


-- ----------------------------
-- Table structure for tbl_wx_label_chatroom
-- ----------------------------
DROP TABLE IF EXISTS `tbl_wx_label_chatroom`;
CREATE TABLE `tbl_wx_label_chatroom` (
  `id` bigint NOT NULL AUTO_INCREMENT COMMENT '主键',
  `cid` int DEFAULT NULL COMMENT '客户id',
  `wechatid` varchar(255) DEFAULT NULL COMMENT '微信id',
  `labelid` varchar(255) DEFAULT '0' COMMENT '标签ID',
  `chatroomid` varchar(255) DEFAULT NULL COMMENT '群id',
  `chatroomsize` int DEFAULT NULL COMMENT '群成员数量',
  `remark` varchar(500) DEFAULT NULL COMMENT '备用字段',
  `wxremark` varchar(500) DEFAULT NULL,
  `create_time` datetime DEFAULT NULL COMMENT '创建时间',
  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB AUTO_INCREMENT=1059 DEFAULT CHARSET=utf8mb4  COMMENT='标签群对应表';


-- ----------------------------
-- Table structure for tbl_wx_messagetag
-- ----------------------------
DROP TABLE IF EXISTS `tbl_wx_messagetag`;
CREATE TABLE `tbl_wx_messagetag` (
  `id` int(11) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `cid` int(11) DEFAULT NULL COMMENT '客户id',
  `type` varchar(128) DEFAULT NULL COMMENT '资源类型',
  `wechatid` varchar(128) DEFAULT NULL COMMENT '微信id',
  `friendwechatid` varchar(128) DEFAULT NULL COMMENT '好友id',
  `msgserverid` varchar(128) DEFAULT NULL COMMENT '消息唯一id',
  `create_time` datetime DEFAULT NULL COMMENT '创建时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `cid` (`cid`,`type`,`wechatid`,`friendwechatid`,`msgserverid`)
) ENGINE=InnoDB AUTO_INCREMENT=100 DEFAULT CHARSET=utf8mb4 COMMENT='消息标识临时表';



