package com.jubotech.business.web.controller.pc;

import java.util.List;

import com.jubotech.business.web.domain.*;
import com.jubotech.business.web.service.*;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.WebDataBinder;
import org.springframework.web.bind.annotation.CrossOrigin;
import org.springframework.web.bind.annotation.InitBinder;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import com.github.pagehelper.PageInfo;
import com.jubotech.business.web.domain.query.TaskQuery;
import com.jubotech.business.web.domain.req.TaskTimeVo;
import com.jubotech.framework.common.ResultInfo;

@Controller
@CrossOrigin
@RequestMapping("/pc")
public class CustomMethodsController {
	 
	@InitBinder
    public void initListBinder(WebDataBinder binder){
        // 设置需要包裹的元素个数，默认为256
		binder.setAutoGrowNestedPaths(true);  
        binder.setAutoGrowCollectionLimit(6000);
    }

	@Autowired
	private AccountService accountService;

	@Autowired
	private TaskTimeService taskTimeService;

	@Autowired
	private CommontagService commontagService;

	@Autowired
	private CommontermService commontermService;

	@Autowired
	private WxContactService weChatContactService;

	@Autowired
	private WxAccountService wxAccountService;
	
	@Autowired
	private SysAutoSettingService sysAutoSettingService;
    
  
	/**
	 * 获取公共的标签
	 * 
	 * @return
	 */
	@PostMapping("/GetCommonTags")
	@ResponseBody
	public ResultInfo GetCommonTags(CommontagInfo req) {
		Integer id = (int) req.getId();
		String name = req.getName();
		if (!StringUtils.isEmpty(name) && name.equals("pc")) {// 获取公共的标签
			AccountInfo account = accountService.findAccountInfoByid(id);
			if (null != account) {
				List<CommontagInfo> list = commontagService.getAllCommontagInfoByCid(account.getCid());
				return ResultInfo.success(list);
			}
		}
		return ResultInfo.fail();
	}

	/**
	 * 获取公共术语
	 * 
	 * @return
	 */
	@PostMapping("/GetCommonTerms")
	@ResponseBody
	public ResultInfo GetCommonTerms(CommontermInfo req) {
		Integer id = (int) req.getId();
		String name = req.getName();
		if (!StringUtils.isEmpty(name) && name.equals("pc")) {// pc端获取公共术语
			AccountInfo account = accountService.findAccountInfoByid(id);
			if (null != account) {
				List<CommontermInfo> list = commontermService.getAllCommontermInfoByCid(account.getCid());
				return ResultInfo.success(list);
			}
		}
		return ResultInfo.fail();
	}

	 
   

	/**
	 * 添加定时任务
	 * 
	 * @param req
	 * @return
	 */
	@PostMapping("/AddTaskTimeInfo")
	@ResponseBody
	public ResultInfo AddTaskTimeInfo(TaskTimeVo req) {
		AccountInfo info = accountService.findAccountInfoByid(req.getAccountid());
		if (null != info) {
			req.setCid(info.getCid());
			return taskTimeService.savePcTask(req);
		}
		return ResultInfo.fail();
	}

	/**
	 * 获取任务列表
	 * 
	 * @return
	 */
	@PostMapping("/GetTaskInfoList")
	@ResponseBody
	public ResultInfo GetTaskInfoList(TaskQuery req) {
		if (null != req) {
			PageInfo<TaskTimeInfo> list = taskTimeService.pageList(req);
			return ResultInfo.success(list);
		}
		return ResultInfo.fail();
	}
	
	
	/**
	 * 定时任务状态更新
	 * 
	 * @return
	 */
	@PostMapping("/TaskStateUpdate")
	@ResponseBody
	public ResultInfo TaskStateUpdate(TaskTimeInfo req) {
		if (null != req) {
			 taskTimeService.taskStateUpdate(req);
			 return ResultInfo.success();
		}
		return ResultInfo.fail();
	}
	
	
	/**
	 * 任务详情统计
	 * 
	 * @return
	 */
	@PostMapping("/TaskDetail")
	@ResponseBody
	public ResultInfo TaskDetail(TaskTimeInfo req) {
		if (null != req) {
			return taskTimeService.taskDetail(req);
		}
		return ResultInfo.fail();
	}
	

	/**
	 * 自动任务详情列表
	 * 
	 * @return
	 */
	@PostMapping("/AutoTaskDetailList")
	@ResponseBody
	public ResultInfo AutoTaskDetailList(SysAutoSetting req) {
		if (null != req) {
			SysAutoSetting info = sysAutoSettingService.findSysAutoSettingByWeChatId(req.getCid(),req.getAuto_type(),req.getWechatId());
			return ResultInfo.success(info);
		}
		return ResultInfo.fail();
	}

	/**
	 * 自动任务更新
	 * 
	 * @return
	 */
	@PostMapping("/AutoTaskUpdate")
	@ResponseBody
	public ResultInfo AutoTaskUpdate(SysAutoSetting req) {
		if (null != req) {
			SysAutoSetting info = sysAutoSettingService.insert(req);
			return ResultInfo.success(info);
		}
		return ResultInfo.fail();
	}

	/**
	 * 获取微信好友列表 tag:暂时未用到
	 *
	 * @return
	 */
	@PostMapping("/GetWechatFriendList")
	@ResponseBody
	public ResultInfo GetWechatFriendList(WxContactInfo req) {
		if (null != req) {
			List<WxContactInfo> list = weChatContactService.findContactinfoByWeChatId(req.getCid(), req.getWechatid());
			return ResultInfo.success(list);
		}
		return ResultInfo.fail();
	}

	/**
	 * 获取公共的标签
	 *
	 * @return
	 */
	@PostMapping("/GetWeChatsReq")
	@ResponseBody
	public ResultInfo GetWeChatsReq(Integer id) {
		AccountInfo  account = accountService.findAccountInfoByid(id);
		if(null != account){
			List<WxAccountInfo> list =	wxAccountService.findWeChatAccountInfo(account.getCid(), account.getId());
			return ResultInfo.success(list);
		}
		return ResultInfo.fail();
	}
}
