package com.jubotech.business.web.service;

import java.util.Arrays;
import java.util.Date;
import java.util.Set;
import java.util.stream.Collectors;

import javax.annotation.Resource;

import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jubotech.business.web.dao.MessageDao;
import com.jubotech.business.web.domain.Message;
import com.jubotech.business.web.domain.query.MessageQuery;
import com.jubotech.framework.common.ResultInfo;
import com.jubotech.framework.common.ServiceException;

import tk.mybatis.mapper.entity.Example;

@Service
@Transactional // 支持事务
public class MessageService {

	@Resource
	private MessageDao messageDao;

	public PageInfo<Message> pageList(MessageQuery query) {
		PageHelper.startPage(query.getPage(), query.getRows());
         
		Example example = new Example(Message.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("cid", query.getCid());
		 
		if(null != query.getWxId()) {
			criteria.andEqualTo("WxId",query.getWxId());
		}
		
		if(null != query.getFriendWxid()) {
			criteria.andEqualTo("ConvId",query.getFriendWxid());
		}
		 
		if(!StringUtils.isEmpty(query.getStart())) {
			criteria.andGreaterThanOrEqualTo("CreateTime",query.getStart());
		}
		
		if(!StringUtils.isEmpty(query.getEnd())) {
			criteria.andLessThanOrEqualTo("CreateTime", query.getEnd());
		}
		
		if (StringUtils.isNotBlank(query.getContent())) {
			criteria.andLike("Content", "%" + query.getContent() + "%");
		}
		
		example.orderBy("id").desc();
		return new PageInfo<>(messageDao.selectByExample(example));
		 
	}

	public int deleteByIds(String ids) {
		if (StringUtils.isBlank(ids)) {
			throw new ServiceException("invalid param");
		}
		String[] idArray = StringUtils.split(ids, ",");
		Set<String> userIds = Arrays.stream(idArray).filter(StringUtils::isNotBlank).collect(Collectors.toSet());
		Example example = new Example(Message.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andIn("id", userIds);

		return messageDao.deleteByExample(example);
	}

	 
	public Message getKeyWordsByid(Integer id) {
		Message user = messageDao.selectByPrimaryKey(id);
		return user;
	}

	public ResultInfo insert(Message info) {
		ResultInfo res = new ResultInfo();
		try {
			info.setCreate_time(new Date());
			messageDao.insert(info);
		} catch (Exception e) {
			return ResultInfo.fail("添加失败");
		}
		return res;
	}

	public ResultInfo update(Message info) {
		ResultInfo res = new ResultInfo();
		try {
			info.setCreate_time(new Date());
			messageDao.updateByPrimaryKey(info);
		} catch (Exception e) {
			return ResultInfo.fail("修改失败");
		}
		return res;
	}
 

}
