package com.jubotech.business.web.service;

import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.google.protobuf.ByteString;
import com.google.protobuf.util.JsonFormat;
import com.jubotech.business.web.dao.TaskTimeDao;
import com.jubotech.business.web.dao.TimeTaskDetailsDao;
import com.jubotech.business.web.domain.TaskTimeInfo;
import com.jubotech.business.web.domain.TimeTaskDetails;
import com.jubotech.business.web.domain.query.TaskQuery;
import com.jubotech.business.web.domain.req.FriendVo;
import com.jubotech.business.web.domain.req.MessageVo;
import com.jubotech.business.web.domain.req.TaskTimeVo;
import com.jubotech.framework.common.ResultInfo;
import com.jubotech.framework.domain.base.DBPage;
import com.jubotech.framework.netty.utils.MsgIdBuilder;
import com.jubotech.framework.util.DateUtil;
import com.jubotech.framework.util.JsonUtils;
import com.jubotech.framework.util.StringUtil;

import Im.Scrm.Ww.Proto.WAddCustomerFromSearchTask.AddCustomerFromSearchTaskMessage;
import Im.Scrm.Ww.Proto.WPostSnsTask.MediaMessage;
import Im.Scrm.Ww.Proto.WPostSnsTask.PostSnsTaskMessage;
import Im.Scrm.Ww.Proto.WTalkToFriendTask.TalkToFriendTaskMessage;
import Im.Scrm.Ww.Proto.WTransport.EnumContentType;
import tk.mybatis.mapper.entity.Example;

@Service
@Transactional // 支持事务
public class TaskTimeService {

	@Autowired
	private TaskTimeDao taskTimeDao;

	@Autowired
	private TimeTaskDetailsDao timeTaskDetailsDao;

	public List<TaskTimeInfo> queryTaskTimeInfoByAccountId(TaskTimeInfo info) {
		DBPage page = new DBPage(info.getPageSize(), (info.getPageNo() - 1) * info.getPageSize());
		return taskTimeDao.queryTaskTimeInfoByAccountId(page, info.getAccountid(), info.getTasktype(), info.getState());
	}

	public PageInfo<TaskTimeInfo> pageList(TaskQuery query) {
		PageHelper.startPage(query.getPage(), query.getRows());

		Example example = new Example(TaskTimeInfo.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andEqualTo("cid", query.getCid());
		if (null != query.getAccountid() && 0 != query.getAccountid()) {
			criteria.andEqualTo("accountid", query.getAccountid());
		}
		if (null != query.getTasktype() && 0 != query.getTasktype()) {
			criteria.andEqualTo("tasktype", query.getTasktype());
		}
		if (null != query.getState()) {
			criteria.andEqualTo("state", query.getState());
		}
		example.orderBy("id").desc();
		return new PageInfo<>(taskTimeDao.selectByExample(example));

	}

	public void taskStateUpdate(TaskTimeInfo info) {
		TaskTimeInfo task = findTaskTimeInfoByid(info.getId());
		if (null != task) {
			// 状态 -1暂停 0已完成 1开启中 2取消
			List<TimeTaskDetails> list = timeTaskDetailsDao.findTimeTaskDetailsByTid(info.getId(), 1);// 查询开启中的
			if (null != list && list.size() > 0) {
				stateUpdate(info, list);
			}

			List<TimeTaskDetails> list1 = timeTaskDetailsDao.findTimeTaskDetailsByTid(info.getId(), -1);// 查询暂停的
			if (null != list1 && list1.size() > 0) {
				stateUpdate(info, list1);
			}

			List<TimeTaskDetails> list2 = timeTaskDetailsDao.findTimeTaskDetailsByTid(info.getId(), 2);// 查询取消的
			if (null != list2 && list2.size() > 0) {
				stateUpdate(info, list2);
			}

			task.setState(info.getState());

			try {
				if (Objects.equals(info.getState(),1)) {// 开启中
					String dataStr = DateUtil.convertDate2String(new Date(), DateUtil.DATE_FORMAT_4);
					task.setExecute_time(dataStr);
				}

				taskTimeDao.update(task);
			} catch (Exception e) {
				e.printStackTrace();
			}

		}

	}

	public ResultInfo taskDetail(TaskTimeInfo info) {
		if (null != info && null != info.getId() && info.getId() > 0) {
			// 状态 -1暂停 0已完成 1开启中 2取消
			Integer task_allSize = timeTaskDetailsDao.findTimeTaskDetailsCount(info.getId(), null);
			Integer task_startSize = timeTaskDetailsDao.findTimeTaskDetailsCount(info.getId(), 1);
			Integer task_endSize = timeTaskDetailsDao.findTimeTaskDetailsCount(info.getId(), 0);
			Integer task_stopSize = timeTaskDetailsDao.findTimeTaskDetailsCount(info.getId(), -1);
			Integer task_cancelSize = timeTaskDetailsDao.findTimeTaskDetailsCount(info.getId(), 2);
			Integer task_successSize = timeTaskDetailsDao.findTimeTaskDetailsTaskResultCount(info.getId(), "true");
			Integer task_failSize = timeTaskDetailsDao.findTimeTaskDetailsTaskResultCount(info.getId(), "false");

			Map<String, Object> data = new HashMap<>();
			data.put("task_allSize", task_allSize);// 任务总数
			data.put("task_startSize", task_startSize);// 正在执行的任务数
			data.put("task_endSize", task_endSize);// 已完成的任务数
			data.put("task_stopSize", task_stopSize);// 已暂停的任务数
			data.put("task_cancelSize", task_cancelSize);// 已取消的任务数
			data.put("task_successSize", task_successSize);// 执行成功的任务数
			data.put("task_failSize", task_failSize);// 执行失败的任务数

			return ResultInfo.success(data);
		}
		return ResultInfo.fail();
	}

	private void stateUpdate(TaskTimeInfo info, List<TimeTaskDetails> list) {
		for (TimeTaskDetails detail : list) {
			detail.setState(info.getState());
			try {

				if (Objects.equals(info.getState(),1)) {// 开启中
					String str = detail.getExecute_time();
					String[] strs = str.split(" ");
					if (strs.length > 1) {

						String secondStr = strs[1];
						String dataStr = DateUtil.convertDate2String(new Date(), DateUtil.DATE_FORMAT_1);
						String newTimeStr = dataStr + " " + secondStr;

						detail.setExecute_time(newTimeStr);
					}
				}

				timeTaskDetailsDao.updateState(detail);
			} catch (Exception e) {
				e.printStackTrace();
			}
		}
	}

	public TaskTimeInfo findTaskTimeInfoByid(Integer id) {
		return taskTimeDao.findTaskTimeInfoByid(id);
	}

	public void delete(Integer id) {
		try {
			// 先删除子任务
			timeTaskDetailsDao.deleteByTid(id);
			// 再删除主任务
			TaskTimeInfo user = new TaskTimeInfo();
			user.setId(id);
			taskTimeDao.delete(user);
		} catch (Exception e) {
			e.printStackTrace();
		}
	}

	public void updateState(TaskTimeInfo info) {
		taskTimeDao.updateState(info);
	}

	public List<TaskTimeInfo> findTaskTimeByTime(String execute_time) {
		return taskTimeDao.findTaskTimeByTime(execute_time);
	}

	public List<TimeTaskDetails> findTimeTaskDetailsByTid(Integer tid) {
		return timeTaskDetailsDao.findTimeTaskDetailsByTid(tid, 1);
	}

	private static void saveGroupSendTimeTaskDetail(TaskTimeInfo info, TimeTaskDetailsDao timeTaskDetailsDao) {
		if (null != info.getId()) {
			List<String> wechatList = info.getWechatList();
			if (null != wechatList && wechatList.size() > 0) {
				wechatList = StringUtil.removeRepeat(wechatList);// 去除重复
				talkMsgToFriend(info, timeTaskDetailsDao, wechatList);
			}
		}

	}

	private static void talkMsgToFriend(TaskTimeInfo info, TimeTaskDetailsDao timeTaskDetailsDao, List<String> friends) {
		 
		String executeTime = info.getExecute_time();
		Date newDate = DateUtil.convertString2Date(executeTime, DateUtil.DATE_FORMAT_4);
		Integer betweenTime = 1;
		if(info.getBetween_time()!=null){
			betweenTime = info.getBetween_time();
		}
		
		for (String friend : friends) {
			
			String newExecuteTime= DateUtil.convertDate2String(newDate, DateUtil.DATE_FORMAT_4);
			
			String msgStr = "";
			String jsonStr = info.getContent();
			List<MessageVo> list = JsonUtils.json2Bean(jsonStr);
			 
			for (int i = 0; i < list.size(); i++) {
				MessageVo msg = list.get(i);
				ByteString byteString = ByteString.copyFromUtf8(msg.getContent());
				
				TalkToFriendTaskMessage.Builder build = TalkToFriendTaskMessage.newBuilder();
				build.setWxId(Long.valueOf(info.getWechatId()));
				build.setConvId(Long.valueOf(Long.valueOf(friend)));
				build.setContent(byteString);
				build.setTaskId(MsgIdBuilder.getId());
				if (msg.getContentType().equalsIgnoreCase("Text")) {// 文本类型
					build.setContentType(EnumContentType.Text);
				} else if (msg.getContentType().equalsIgnoreCase("Picture")) {// 图片类型
					build.setContentType(EnumContentType.Picture);
				} else if (msg.getContentType().equalsIgnoreCase("Voice")) {// 语音类型
					build.setContentType(EnumContentType.Voice);
				} else if (msg.getContentType().equalsIgnoreCase("Video")) {// 视频类型
					build.setContentType(EnumContentType.Video);
				} else if (msg.getContentType().equalsIgnoreCase("Link")) {// 链接类型
					build.setContentType(EnumContentType.Link);
				} else if (msg.getContentType().equalsIgnoreCase("WeApp")) {// 小程序
					build.setContentType(EnumContentType.WeApp);
				} else if (msg.getContentType().equalsIgnoreCase("NameCard")) {// 名片
					build.setContentType(EnumContentType.NameCard);
				}
				try {
					TalkToFriendTaskMessage msg1 = build.build();
					String json = JsonFormat.printer().print(msg1);

					msgStr = msgStr + json;
					if (i != (list.size() - 1)) {
						msgStr = msgStr + "&&";
					}

				} catch (Exception e) {
					e.printStackTrace();
				}
			}

			if (null != msgStr) {
				try {
					if (!StringUtils.isEmpty(msgStr)) {
						TimeTaskDetails detail = new TimeTaskDetails();
						detail.setTid(info.getId());
						detail.setExecute_time(newExecuteTime);
						detail.setJson_content(msgStr);
						timeTaskDetailsDao.insert(detail);
					}
				} catch (Exception e) {
					e.printStackTrace();
				}
			}
			
            newDate = DateUtil.offsetSecode(newDate, betweenTime);

		}

	}

	private static void saveAddFriendsTimeTaskDetail(TaskTimeInfo info, TimeTaskDetailsDao timeTaskDetailsDao) {
		if (null != info.getId()) {

			Date newDate = DateUtil.convertString2Date(info.getExecute_time(), DateUtil.DATE_FORMAT_4);
			Integer betweenTime = 30;
			if (info.getBetween_time() != null) {
				betweenTime = info.getBetween_time();
			}

			List<String> friendAddList = info.getFriendAddList();

			if (null != friendAddList && friendAddList.size() > 0) {
				for (String str : friendAddList) {
					FriendVo vo = JsonUtils.stringToObject(str);
					AddCustomerFromSearchTaskMessage.Builder build = AddCustomerFromSearchTaskMessage.newBuilder();
					build.setKey(vo.getPhoneNumber());
					build.addLabels(vo.getLabel());
					build.setWxId(Long.valueOf(info.getWechatId()));
					build.setTaskId(MsgIdBuilder.getId());
					AddCustomerFromSearchTaskMessage msg = build.build();
					if (null != msg) {
						try {
							String json = JsonFormat.printer().print(msg);
							if (!StringUtils.isEmpty(json)) {
								TimeTaskDetails detail = new TimeTaskDetails();
								detail.setTid(info.getId());
								detail.setExecute_time(DateUtil.convertDate2String(newDate, DateUtil.DATE_FORMAT_4));
								detail.setJson_content(json);
								timeTaskDetailsDao.insert(detail);
							}
						} catch (Exception e) {
							e.printStackTrace();
						}
					}
					newDate = DateUtil.offsetSecode(newDate, betweenTime);
				}
			}
		}

	}

	private static void savepostSnsTaskDetail(TaskTimeInfo info, TimeTaskDetailsDao timeTaskDetailsDao) {
		if (null != info.getId()) {

			String wechatId = info.getWechatId();

			TimeTaskDetails detail = new TimeTaskDetails();
			detail.setTid(info.getId());
			detail.setExecute_time(info.getExecute_time());
			timeTaskDetailsDao.insert(detail);

			if (null != detail.getId()) {
				// 设置附件
				MediaMessage.Builder media = MediaMessage.newBuilder();
				media.setTypeValue(info.getRestype());
				media.addAllContent(StringUtil.stringToList(info.getAttachtcontent()));

				// 按微信号生成需要发的消息内容
				PostSnsTaskMessage.Builder buider = PostSnsTaskMessage.newBuilder();
				buider.setContent(info.getContent());
				buider.setMedia(media);
				buider.setTaskId(MsgIdBuilder.getId());
				buider.setWxId(Long.valueOf(wechatId));

				PostSnsTaskMessage msg = buider.build();
				String json = null;
				if (null != msg) {
					try {
						json = JsonFormat.printer().print(msg);
					} catch (Exception e) {
						e.printStackTrace();
					}
				}
				if (!StringUtils.isEmpty(json)) {
					TimeTaskDetails tds = new TimeTaskDetails();
					tds.setId(detail.getId());
					tds.setJson_content(json);
					timeTaskDetailsDao.updateJsonContent(tds);
				}
			}

		}

	}

	/**
	 * pc端添加定时任务
	 * 
	 * @param info
	 * @return
	 */
	public ResultInfo savePcTask(TaskTimeVo req) {
		ResultInfo res = ResultInfo.success();
		try {

			TaskTimeInfo info = new TaskTimeInfo();
			BeanUtils.copyProperties(req, info);

			// 主任务存储数据库
			info.setState(1);// 1开启中 0已完成
			taskTimeDao.insert(info);

			// 子任务分别处理 存储子任务详情
			if (info.getTasktype() == 1 || info.getTasktype() == 2 || info.getTasktype() == 3) {// 1、群发客户；2、群发联系人；3、群发群聊
				saveGroupSendTimeTaskDetail(info, timeTaskDetailsDao);
			}
			if (info.getTasktype() == 4) {// 发朋友圈
				savepostSnsTaskDetail(info, timeTaskDetailsDao);
			}

			if (info.getTasktype() == 5) {// 添加好友
				saveAddFriendsTimeTaskDetail(info, timeTaskDetailsDao);
			}

		} catch (Exception e) {
			res = ResultInfo.fail();
			e.printStackTrace();
		}

		return res;
	}

}
