package com.jubotech.business.web.service;

import java.util.Arrays;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.jubotech.business.web.dao.AccountDao;
import com.jubotech.business.web.dao.CustomerDao;
import com.jubotech.business.web.dao.WxAccountDao;
import com.jubotech.business.web.domain.AccountInfo;
import com.jubotech.business.web.domain.WxAccountInfo;
import com.jubotech.business.web.domain.query.DeviceQuery;
import com.jubotech.framework.common.ResultInfo;
import com.jubotech.framework.common.ServiceException;
import com.jubotech.framework.netty.common.Constant;

import tk.mybatis.mapper.entity.Example;

@Service
@Transactional // 支持事务
public class WxAccountService {

	@Autowired
	private CustomerDao customerDao;

	@Autowired
	private WxAccountDao weChatAccountDao;

	@Autowired
	private AccountDao accountDao;

	public PageInfo<WxAccountInfo> pageList(DeviceQuery query) {
		PageHelper.startPage(query.getPage(), query.getRows());
		return new PageInfo<>(weChatAccountDao.pageList(query));
	}

	public void deleteByIds(String ids) {
		if (StringUtils.isBlank(ids)) {
			throw new ServiceException("invalid param");
		}
		String[] idArray = StringUtils.split(ids, ",");
		Set<String> userIds = Arrays.stream(idArray).filter(StringUtils::isNotBlank).collect(Collectors.toSet());
		Example example = new Example(WxAccountInfo.class);
		Example.Criteria criteria = example.createCriteria();
		criteria.andIn("id", userIds);

		weChatAccountDao.deleteByExample(example);

		refreshCache();// 刷新设备缓存

	}

	public void delete(Integer id) {
		if (id != null) {
			weChatAccountDao.deleteByPrimaryKey(id);
		}
	}

	public ResultInfo insert(WxAccountInfo info) {
		ResultInfo res = new ResultInfo();
		Integer count = customerDao.getCustomerPhoneCount(info.getCid());// 该客户端的的设备数
		Integer pcount = weChatAccountDao.getPhoneAllCountByCid(info.getCid());// 已经绑定的设备数
		if (pcount >= count) {
			return ResultInfo.fail("超过账号个数");
		} else {
			try {
				String deviceid = info.getDeviceid().trim();
				info.setDeviceid(deviceid);
				weChatAccountDao.insert(info);
			} catch (Exception e) {
				return ResultInfo.fail("添加失败");
			}
		}

		refreshCache();// 刷新设备缓存

		return res;
	}

	public ResultInfo updatePC(WxAccountInfo info) {
		ResultInfo res = new ResultInfo();
		try {
			WxAccountInfo wxInfo = getWeChatAccountByid(info.getId());
			wxInfo.setAccountid(info.getAccountid());
			wxInfo.setDevnickname(info.getDevnickname());
			wxInfo.setBrand(info.getBrand());
			wxInfo.setModule(info.getModule());
			wxInfo.setDeviceid(info.getDeviceid().trim());
			weChatAccountDao.update(wxInfo);
			refreshCache();// 刷新设备缓存
		} catch (Exception e) {
			return ResultInfo.fail("修改失败");
		}
		return res;
	}

	public ResultInfo update(WxAccountInfo info) {
		ResultInfo res = new ResultInfo();
		try {
			weChatAccountDao.update(info);

			refreshCache();// 刷新设备缓存
		} catch (Exception e) {
			return ResultInfo.fail("修改失败");
		}
		return res;
	}

	public boolean binding(Integer accountid, String ids) {
		try {
			if (null != accountid && !StringUtils.isEmpty(ids)) {
				AccountInfo account = accountDao.findAccountInfoByid(accountid);
				String[] s = ids.split(",");
				if (null != s && s.length > 0) {
					for (int i = 0; i < s.length; i++) {
						Integer id = Integer.valueOf(s[i]);
						WxAccountInfo phone = weChatAccountDao.findWeChatAccountInfoByid(id);
						if (null != account && null != phone) {
							bangding(phone, id, accountid);
						}
					}
				} else {
					Integer id = Integer.valueOf(ids);
					WxAccountInfo phone = weChatAccountDao.findWeChatAccountInfoByid(id);
					if (null != account && null != phone) {
						bangding(phone, id, accountid);
					}
				}
				return true;
			} else {
				return false;
			}
		} catch (Exception e) {
			e.printStackTrace();
			return false;
		}
	}

	private void bangding(WxAccountInfo phone, Integer id, Integer accountid) {
		if (null != phone) {
			// 先绑定 操作员 及部门
			weChatAccountDao.binding(id, String.valueOf(accountid));
		}
	}

	public void updateLoginTime(String deviceid) {
		weChatAccountDao.updateLoginTime(deviceid);
	}

	public WxAccountInfo getWeChatAccountByid(Integer id) {
		WxAccountInfo user = weChatAccountDao.findWeChatAccountInfoByid(id);
		return user;
	}

	public WxAccountInfo findWeChatAccountInfoByDeviceid(String deviceid) {
		WxAccountInfo user = weChatAccountDao.findWeChatAccountInfoByDeviceid(deviceid);
		return user;
	}

	public WxAccountInfo findWeChatAccountInfoByWeChatId(String weChatId) {
		WxAccountInfo user = weChatAccountDao.findWeChatAccountInfoByWeChatId(weChatId);
		return user;
	}

	public List<WxAccountInfo> findWeChatAccountInfo(Integer cid, Integer accountid) {
		return weChatAccountDao.findWeChatAccountInfo(cid, accountid);
	}

	public List<WxAccountInfo> findAllWeChatAccountInfo(Integer isonline) {
		return weChatAccountDao.findAllWeChatAccountInfo(isonline);
	}

	public List<WxAccountInfo> findWeChatAccountInfoByWeChatIdNotEqualsDeviceid(String wechatid, String deviceid) {
		return weChatAccountDao.findWeChatAccountInfoByWeChatIdNotEqualsDeviceid(wechatid, deviceid);
	}

	/**
	 * 刷新缓存
	 */
	public List<WxAccountInfo> refreshCache() {
		List<WxAccountInfo> accList = weChatAccountDao.findAllIsLoginAccountWechatInfo();
		if (null != accList && accList.size() > 0) {
			Constant.accountInfoList = accList;
		}
		return accList;
	}

}
