package com.jubotech.framework.netty.async;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.xm.Similarity;

import com.google.protobuf.Message;
import com.jubotech.business.web.domain.AccountInfo;
import com.jubotech.business.web.domain.KeyWords;
import com.jubotech.business.web.domain.LabelChatRoom;
import com.jubotech.business.web.domain.SysAutoSetting;
import com.jubotech.business.web.domain.WxAccountInfo;
import com.jubotech.business.web.service.AccountService;
import com.jubotech.business.web.service.KeyWordsService;
import com.jubotech.business.web.service.LabelChatRoomService;
import com.jubotech.business.web.service.MessageService;
import com.jubotech.business.web.service.SysAutoSettingService;
import com.jubotech.business.web.service.WxAccountService;
import com.jubotech.framework.common.AutoType;
import com.jubotech.framework.netty.common.Constant;
import com.jubotech.framework.netty.utils.ByteStringToString;
import com.jubotech.framework.netty.utils.MessageUtil;
import com.jubotech.framework.netty.utils.MsgIdBuilder;
import com.jubotech.framework.netty.utils.NettyConnectionUtil;
import com.jubotech.framework.util.DateUtil;

import Im.Scrm.Ww.Proto.WAcceptCustomerTask.AcceptCustomerTaskMessage;
import Im.Scrm.Ww.Proto.WChatRoomActionTask.ChatRoomActionTaskMessage;
import Im.Scrm.Ww.Proto.WChatRoomActionTask.EnumChatRoomAction;
import Im.Scrm.Ww.Proto.WCustomerPushNotice.CustomerMessage;
import Im.Scrm.Ww.Proto.WFriendTalkNotice.FriendTalkNoticeMessage;
import Im.Scrm.Ww.Proto.WTaskResultNotice.TaskResultNoticeMessage;
import Im.Scrm.Ww.Proto.WTransport.EnumContentType;
import Im.Scrm.Ww.Proto.WTransport.EnumMsgType;
import Im.Scrm.Ww.Proto.WTransport.TransportMessage;
import Im.Scrm.Ww.Proto.WwOfflineNotice.WwOfflineNoticeMessage;
import io.netty.channel.ChannelHandlerContext;
import lombok.extern.slf4j.Slf4j;

@Service
@EnableAsync
@Slf4j
public class AsyncTaskService {
	@Autowired
	private AccountService accountService;

	@Autowired
	private WxAccountService weChatAccountService;

	@Autowired
	private KeyWordsService keyWordsService;
	
	@Autowired
	private SysAutoSettingService sysAutoSettingService;
	
	@Autowired
	private LabelChatRoomService labelChatRoomService;
	
	@Autowired
	private MessageService messageService;

	@Autowired
	private NettyConnectionUtil nettyConnectionUtil;

	/**
	 * 转发消息给pc客户端
	 * 
	 * @param wechatId
	 * @param type
	 * @param req
	 */
	@Async
	public void msgSend2pc(String wechatId, EnumMsgType type, Message req) {
		if (StringUtils.isEmpty(wechatId)) {
			return;
		}
		try {
			log.info(LocalDateTime.now() + " msgSend2pc 对应的线程名: " + Thread.currentThread().getName());
			// 先从缓存取，如果取不到再用sql取
			List<WxAccountInfo> accountInfoList = Constant.accountInfoList;
			if (null == accountInfoList || accountInfoList.size() == 0) {
				// 刷新缓存
				accountInfoList = weChatAccountService.refreshCache();
			}

			WxAccountInfo account = null;
			if (null != accountInfoList && accountInfoList.size() > 0) {
				for (int i = 0; i < accountInfoList.size(); i++) {
					WxAccountInfo ainfo = accountInfoList.get(i);
					if (null != ainfo && !StringUtils.isEmpty(ainfo.getWxid()) && ainfo.getWxid().equals(wechatId)) {
//						account = accountService.findAccountInfoByid(Integer.valueOf(ainfo.getAccountid()));
						account = ainfo;
						break;
					}
				}
			}

			if (null == account) {
				WxAccountInfo accInfo = weChatAccountService.findWeChatAccountInfoByWeChatId(wechatId);
				if (null != accInfo) {
					account = accInfo;
					// 刷新缓存
					weChatAccountService.refreshCache();
				}
			}

			if (null != account && !StringUtils.isEmpty(account.getAccountid())) {
				List<AccountInfo> accInfo = accountService.queryByIds(account.getAccountid());
				if (null != accInfo) {
					for (AccountInfo info : accInfo) {
						// 转发给pc端
						ChannelHandlerContext chx = nettyConnectionUtil
								.getClientChannelHandlerContextByUserId(info.getAccount());
						if (null != chx) {
							MessageUtil.sendJsonMsg(chx, type, nettyConnectionUtil.getNettyId(chx), null, req);
						}
					}
				}
			}
		} catch (Throwable e) {
			e.printStackTrace();
		}

	}

	/**
	 * 转发消息给手机客户端
	 * 
	 * @param ctx
	 * @param wechatId
	 * @param type
	 * @param vo
	 * @param req
	 */
	@Async
	public void msgSend2Phone(ChannelHandlerContext ctx, String wechatId, EnumMsgType type, TransportMessage vo,
			Message req) {

		try {
			log.info(LocalDateTime.now() + " msgSend2Phone 对应的线程名: " + Thread.currentThread().getName());

			ChannelHandlerContext chx = nettyConnectionUtil.getClientChannelHandlerContextByUserId(wechatId);
			if (null != chx) {
				// 转发给手机端
				MessageUtil.sendMsg(chx, type, vo.getAccessToken(), null, req);
				// 告诉发送方 消息已经收到
				MessageUtil.sendJsonMsg(ctx, EnumMsgType.MsgReceivedAck, vo.getAccessToken(), vo.getId(), null);
			} else {

				// 做个保护，如果微信不在线，则通知pc端，下线其微信
				WxAccountInfo account = weChatAccountService.findWeChatAccountInfoByWeChatId(wechatId);
				if (null != account) {
					account.setIsonline(1);// 下线
					weChatAccountService.update(account);
				}

				// 通知pc端下线其微信
				WwOfflineNoticeMessage resp = WwOfflineNoticeMessage.newBuilder().setWxId(Long.valueOf(wechatId))
						.build();
				MessageUtil.sendJsonMsg(ctx, EnumMsgType.WwOfflineNotice, nettyConnectionUtil.getNettyId(ctx), null,
						resp);
			}
		} catch (Throwable e) {
			e.printStackTrace();
		}
	}

	/**
	 * 关键词匹配
	 * 
	 * @param req
	 * @return
	 */
	@Async
	public void checkKeyWord(FriendTalkNoticeMessage req) {
		try {
			String message = req.getContent().toStringUtf8();
			if (!StringUtils.isEmpty(message) && req.getContentType().equals(EnumContentType.Text)) {
				
				//该微信是否开启了自动回复
				SysAutoSetting sys = sysAutoSettingService.findSettingByWcIdAutoType(String.valueOf(req.getWxId()),AutoType.AUTOTYPE_KEYWORDS);
				if (null == sys) {
					return;
				}
				
				if (StringUtils.isEmpty(sys.getRemarks())) {
					return;
				}
				
				String dateStr = sys.getRemarks();
				String strs[] = dateStr.split(":");
				if(null == strs || strs.length<2){
					return;
				}
				Integer start = Integer.valueOf(strs[0]);//11
				Integer end = Integer.valueOf(strs[1]);//6
				Integer now = DateUtil.getHourOfNow(new Date());//2
				 
				if(now<start && now>end){
					return;
				}
				
				
				// 完全匹配
				List<KeyWords> keyWords = keyWordsService.listByAccountIdKeyType(String.valueOf(req.getWxId()), 0);

				boolean flag = false;

				if (!CollectionUtils.isEmpty(keyWords)) {
					for (KeyWords kw : keyWords) {
						if (!StringUtils.isEmpty(kw.getKeyWord()) && kw.getKeyWord().equals(message)) {
							MessageUtil.sendMsgByType(req.getWxId(), req.getConvId(), kw.getReturnString(),kw.getResourceType());
							flag = true;
							break;
						}
					}
				}

				if (!flag) {
					// 模糊包含匹配
					List<KeyWords> mkeyWords = keyWordsService.listByAccountIdKeyType(String.valueOf(req.getWxId()), 1);
					if (!CollectionUtils.isEmpty(mkeyWords)) {
						for (KeyWords kw : mkeyWords) {
							try {
								if (!StringUtils.isEmpty(kw.getKeyWord()) && message.contains(kw.getKeyWord())) {
									MessageUtil.sendMsgByType(req.getWxId(),req.getConvId(),kw.getReturnString(),kw.getResourceType());
									flag = true;
									break;
								}
							} catch (Exception e) {
								e.printStackTrace();
							}
						}
					}
				}

				if (!flag) {
					// 模糊智能匹配
					List<KeyWords> mkeyWords = keyWordsService.listByAccountIdKeyType(String.valueOf(req.getWxId()), 2);
					if (!CollectionUtils.isEmpty(mkeyWords)) {
						KeyWords hkw =null;
						double result =0;
						for (KeyWords kw : mkeyWords) {
							try {
								System.out.println("begin=" + DateUtil.convertDate2String(new Date()));
								double conceptSimilarityResult = Similarity.cilinSimilarity(kw.getKeyWord(), message);// 词林相似度值
								//double conceptSimilarityResult = Similarity.conceptSimilarity(kw.getKeyWord(), message);//概念相似度值
								if(null == hkw){
									result = conceptSimilarityResult;
									hkw =kw;
								}else{
									if(conceptSimilarityResult>result){
										result = conceptSimilarityResult;
										hkw =kw;
									}
								}
								
							} catch (Exception e) {
								e.printStackTrace();
							}
						}
						System.out.println("result============" + result);
						
						if (result > 0.85) {
							MessageUtil.sendMsgByType(req.getWxId(),req.getConvId(),hkw.getReturnString(),hkw.getResourceType());
						}
						
					}
				}
			}
		} catch (Exception e) {
			e.printStackTrace();
		}

	}
	
	@Async
	public void  checkAddFriends(String wxid,List<CustomerMessage> list){
		if(null != list && list.size()>0){
			
			SysAutoSetting sys = sysAutoSettingService.findSettingByWcIdAutoType(wxid,AutoType.AUTOTYPE_FRIENDREQEST);
			if (null == sys) {
				return;
			}
			
			for(CustomerMessage customer:list){
				AcceptCustomerTaskMessage.Builder bd = AcceptCustomerTaskMessage.newBuilder();
				bd.setWxId(Long.valueOf(wxid));
				bd.setRemoteId(customer.getRemoteId());
				bd.setTaskId(MsgIdBuilder.getId());
				AcceptCustomerTaskMessage req = bd.build();
				
				ChannelHandlerContext chx = nettyConnectionUtil.getClientChannelHandlerContextByUserId(wxid);
		        if (chx != null){
		        	MessageUtil.sendMsg(chx, EnumMsgType.AcceptCustomerTask, null, null, req);
		        }	
			}
		}
	}
	
	

	/**
	 * 是否加入群聊
	 */
	@Async
	public void checkInChatRoom(String wxid,List<CustomerMessage> list) {
		if(null != list && list.size()>0){
			for(CustomerMessage customer:list){
				checkInChatRoom(wxid, customer);
			}
		}
	}
	
	/**
	 * 是否加入群聊
	 */
	public void checkInChatRoom(String wxid,CustomerMessage customer) {
		try {
			  
			if(null == customer){
				return;
			}
			 
			SysAutoSetting sys = sysAutoSettingService.findSettingByWcIdAutoType(wxid,AutoType.AUTOTYPE_INCHATROOM);
			if (null == sys) {
				return;
			}
			
			
			
			//查询数据库是否存在群
			List<Long> labels = customer.getLabelIdsList();
			if(null != labels && labels.size()>0){
				WxAccountInfo account = weChatAccountService.findWeChatAccountInfoByWeChatId(wxid);
				if(null == account || null == account.getCid()){
					return;
				}
				for(Long label:labels){
					LabelChatRoom  labelChatRoom = labelChatRoomService.queryByWechatidLabelidChatroomid(wxid, String.valueOf(label), null);
					if(null == labelChatRoom){
						if(StringUtils.isEmpty(sys.getRemarks())){
							sys.setRemarks(String.valueOf(customer.getRemoteId()));
							sysAutoSettingService.update(sys);
							continue;
						}
						if(sys.getRemarks().equals(customer.getRemoteId())){
							continue;
						}
						  
						//建个群，把自己和该用户拉进去
					    List<Long> wxids = new ArrayList<Long>();
						wxids.add(Long.valueOf(wxid));
						wxids.add(customer.getRemoteId());
						//wxids.add(1688850356934422L);
						wxids.add(Long.valueOf(sys.getRemarks()));
						
						Long taskid= MsgIdBuilder.getId();
						ChatRoomActionTaskMessage.Builder bd = ChatRoomActionTaskMessage.newBuilder();
						bd.addAllMembers(wxids);
						bd.setAction(EnumChatRoomAction.CreateRoom);
						bd.setContent("客户群"+label);
						bd.setTaskId(taskid);
						ChatRoomActionTaskMessage msg = bd.build();
						
						ChannelHandlerContext chx = nettyConnectionUtil.getClientChannelHandlerContextByUserId(wxid);
				        if (chx != null){
				        	MessageUtil.sendMsg(chx, EnumMsgType.ChatRoomActionTask, null, null, msg);
				        	
				        	//把群信息存储
				        	LabelChatRoom lbRoom = new LabelChatRoom();
				        	lbRoom.setWechatid(wxid);
				        	lbRoom.setLabelid(String.valueOf(label));
				        	lbRoom.setChatroomsize(2);
				        	lbRoom.setCid(account.getCid());
				        	lbRoom.setRemark(String.valueOf(taskid));
				        	
				        	labelChatRoomService.insert(lbRoom);
				        }
						 
					}else{
						if(null == labelChatRoom.getChatroomid()){
							return;
						}
						//把该用户拉入群
						List<Long> wxids = new ArrayList<Long>();
						wxids.add(customer.getRemoteId());
						ChatRoomActionTaskMessage.Builder bd = ChatRoomActionTaskMessage.newBuilder();
						bd.addAllMembers(wxids);
						bd.setAction(EnumChatRoomAction.AddMember);
						bd.setTaskId(MsgIdBuilder.getId());
						bd.setConvId(Long.valueOf(labelChatRoom.getChatroomid()));
						ChatRoomActionTaskMessage msg = bd.build();
						
						ChannelHandlerContext chx = nettyConnectionUtil.getClientChannelHandlerContextByUserId(wxid);
				        if (chx != null){
				        	MessageUtil.sendMsg(chx, EnumMsgType.ChatRoomActionTask, null, null, msg);
				        }	
						
				        labelChatRoom.setChatroomsize(labelChatRoom.getChatroomsize()+1);
			        	labelChatRoomService.update(labelChatRoom);
					}
				}
			}
			
			
		} catch (Exception e) {
			e.printStackTrace();
		}

	}
	
	/**
	 * 创建群聊时更新chatroomid
	 * @param req
	 */
	@Async
	public void updateChatRoomId(TaskResultNoticeMessage req) {
		try {
			if(null == req ){
				return;
			}
			 
			if(!req.getTaskType().equals(EnumMsgType.ChatRoomActionTask)){
				return;
			}
			
			LabelChatRoom  labelChatRoom = labelChatRoomService.queryByRemark(String.valueOf(req.getTaskId()));
			if(null != labelChatRoom){
				labelChatRoom.setChatroomid(String.valueOf(req.getExtId()));
				labelChatRoom.setRemark("");
				labelChatRoomService.update(labelChatRoom);
			}
		 
		} catch (Exception e) {
			e.printStackTrace();
		}

	}
	
	
	@Async
	public void saveMsg(FriendTalkNoticeMessage req,String isSend) {
		
		if(!Constant.SAVE_MESSAGE) {
			return;
		}
		
		WxAccountInfo info = weChatAccountService.findWeChatAccountInfoByWeChatId(String.valueOf(req.getWxId()));
		if(null != info) {
			String content = ByteStringToString.bytesToString(req.getContent(), "utf-8");
			com.jubotech.business.web.domain.Message msg = new com.jubotech.business.web.domain.Message();
			msg.setCid(info.getCid());
			msg.setWxId(req.getWxId());
			msg.setConvId(req.getConvId());
			msg.setSenderId(req.getSenderId());
			msg.setContentType(String.valueOf(req.getContentTypeValue()));
			msg.setContent(content);
			msg.setMsgId(req.getMsgId());
			msg.setMsgRemoteId(req.getMsgRemoteId());
			msg.setCreateTime(req.getCreateTime());
			msg.setSenderName(req.getSenderName());
			msg.setRefId(req.getRefId());
			msg.setIsSend(isSend);
			msg.setCreate_time(new Date());
			
			messageService.insert(msg);
		}
		 
	}
	
  
}
