package com.jubotech.framework.netty.handler.socket;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import com.google.protobuf.util.JsonFormat;
import com.jubotech.framework.netty.async.AsyncTaskService;
import com.jubotech.framework.netty.common.Constant;
import com.jubotech.framework.netty.handler.MessageHandler;
import com.jubotech.framework.netty.utils.MessageUtil;

import Im.Scrm.Ww.Proto.WCustomerPushNotice.CustomerPushNoticeMessage;
import Im.Scrm.Ww.Proto.WTransport.EnumErrorCode;
import Im.Scrm.Ww.Proto.WTransport.EnumMsgType;
import Im.Scrm.Ww.Proto.WTransport.TransportMessage;
import io.netty.channel.ChannelHandlerContext;
import lombok.extern.slf4j.Slf4j;

@Service
@Slf4j
public class CustomerPushNoticeHandler implements MessageHandler{
	@Autowired
	private AsyncTaskService asyncTaskService;
	/**
	 * 企业微信推送客户联系人
	 * @author wechatno:tangjinjinwx
	 * @author wechat:happybabby110
	 * @blog http://www.wlkankan.cn
	 */
	@Async
    public  void handleMsg(ChannelHandlerContext ctx, TransportMessage vo) {
        try {
        	CustomerPushNoticeMessage req = vo.getContent().unpack(CustomerPushNoticeMessage.class);
        	log.debug(JsonFormat.printer().print(req)); 
		
        	//是否将用户加入群聊
        	asyncTaskService.checkInChatRoom(String.valueOf(req.getWxId()),req.getContactsList());
			asyncTaskService.msgSend2pc(String.valueOf(req.getWxId()), EnumMsgType.CustomerPushNotice, req);
			
			// 告诉客户端消息已收到
			MessageUtil.sendMsg(ctx, EnumMsgType.MsgReceivedAck, vo.getAccessToken(), vo.getId(), null);
        } catch (Exception e) {
            e.printStackTrace();
            MessageUtil.sendErrMsg(ctx, EnumErrorCode.InvalidParam,vo.getId(), Constant.ERROR_MSG_DECODFAIL);
        }
    }
}