package com.jubotech.framework.netty.handler.socket;
 
import java.time.LocalDateTime;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import com.google.protobuf.util.JsonFormat;
import com.jubotech.framework.netty.async.AsyncTaskService;
import com.jubotech.framework.netty.handler.MessageHandler;
import com.jubotech.framework.netty.utils.MessageUtil;

import Im.Scrm.Ww.Proto.WDownloadFileResultNotice.DownloadFileResultNoticeMessage;
import Im.Scrm.Ww.Proto.WTransport.EnumErrorCode;
import Im.Scrm.Ww.Proto.WTransport.EnumMsgType;
import Im.Scrm.Ww.Proto.WTransport.TransportMessage;
import io.netty.channel.ChannelHandlerContext;
import lombok.extern.slf4j.Slf4j;

@Service
@Slf4j
public class DownloadFileResultNoticeHandler  implements MessageHandler{
	@Autowired
	private AsyncTaskService asyncTaskService; 
 
	/**
	 * 文件类型详细内容通知
	 * @author wechat:happybabby110
	 * @blog http://www.wlkankan.cn
	 */
	@Async
	public void handleMsg(ChannelHandlerContext ctx, TransportMessage vo) {
		try {
			DownloadFileResultNoticeMessage req = vo.getContent().unpack(DownloadFileResultNoticeMessage.class);
			log.debug(JsonFormat.printer().print(req));
			
			log.debug(LocalDateTime.now()+" 微信好友发来聊天消息  对应的线程名: "+Thread.currentThread().getName());
			   
			//消息转发到pc端
			asyncTaskService.msgSend2pc(String.valueOf(req.getWxId()), EnumMsgType.DownloadFileResultNotice, req);
			 
        	// 告诉客户端消息已收到
        	MessageUtil.sendMsg(ctx, EnumMsgType.MsgReceivedAck, vo.getAccessToken(), vo.getId(), null);
        	 
		} catch (Exception e) {
			e.printStackTrace();
			MessageUtil.sendErrMsg(ctx, EnumErrorCode.InvalidParam,vo.getId(), e.getMessage());
		}
	}
	

	 
}