package com.jubotech.framework.netty.handler.socket;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import com.google.protobuf.util.JsonFormat;
import com.jubotech.framework.netty.async.AsyncTaskService;
import com.jubotech.framework.netty.common.Constant;
import com.jubotech.framework.netty.handler.MessageHandler;
import com.jubotech.framework.netty.utils.MessageUtil;
import com.jubotech.framework.netty.utils.NettyConnectionUtil;

import Im.Scrm.Ww.Proto.WCommonTriggerTask.CommonTriggerTaskMessage;
import Im.Scrm.Ww.Proto.WNewCustomerAddedNotice.NewCustomerAddedNoticeMessage;
import Im.Scrm.Ww.Proto.WTransport.EnumErrorCode;
import Im.Scrm.Ww.Proto.WTransport.EnumMsgType;
import Im.Scrm.Ww.Proto.WTransport.TransportMessage;
import io.netty.channel.ChannelHandlerContext;
import lombok.extern.slf4j.Slf4j;

@Service
@Slf4j
public class NewCustomerAddedNoticeHandler implements MessageHandler{
	@Autowired
	private AsyncTaskService asyncTaskService;
	
	@Autowired
	private NettyConnectionUtil nettyConnectionUtil;
	
	/**
	 * 新客户变更通知
	 * @author wechat:happybabby110
	 * @blog http://www.wlkankan.cn
	 */
	@Async
    public  void handleMsg(ChannelHandlerContext ctx, TransportMessage vo) {
        try {
        	NewCustomerAddedNoticeMessage req = vo.getContent().unpack(NewCustomerAddedNoticeMessage.class);
        	log.debug(JsonFormat.printer().print(req));
        	  
			asyncTaskService.msgSend2pc(String.valueOf(req.getWxId()), EnumMsgType.NewCustomerAddedNotice, req);
			// 告诉客户端消息已收到
			MessageUtil.sendMsg(ctx, EnumMsgType.MsgReceivedAck, vo.getAccessToken(), vo.getId(), null);
			
			//拉取一下新的客户
			CommonTriggerTaskMessage.Builder bd = CommonTriggerTaskMessage.newBuilder();
			bd.setWxId(req.getWxId());
			CommonTriggerTaskMessage task = bd.build();
			// 将消息转发送给手机客户端
			ChannelHandlerContext chx = nettyConnectionUtil.getClientChannelHandlerContextByUserId(String.valueOf(req.getWxId()));
			if (null != chx) {
				// 转发给手机端
				MessageUtil.sendMsg(chx, EnumMsgType.TriggerNewCustomerTask, vo.getAccessToken(), null, task);
			}	
			
			
			
        } catch (Exception e) {
            e.printStackTrace();
            MessageUtil.sendErrMsg(ctx, EnumErrorCode.InvalidParam,vo.getId(), Constant.ERROR_MSG_DECODFAIL);
        }
    }
}