package com.jubotech.framework.netty.handler.socket;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import com.google.protobuf.util.JsonFormat;
import com.jubotech.framework.netty.async.AsyncTaskService;
import com.jubotech.framework.netty.common.Constant;
import com.jubotech.framework.netty.handler.MessageHandler;
import com.jubotech.framework.netty.utils.MessageUtil;

import Im.Scrm.Ww.Proto.WTaskResultNotice.TaskResultNoticeMessage;
import Im.Scrm.Ww.Proto.WTransport.EnumErrorCode;
import Im.Scrm.Ww.Proto.WTransport.EnumMsgType;
import Im.Scrm.Ww.Proto.WTransport.TransportMessage;
import io.netty.channel.ChannelHandlerContext;
import lombok.extern.slf4j.Slf4j;

@Service
@Slf4j
public class TaskResultNoticeHandler implements MessageHandler{
	@Autowired
	private AsyncTaskService asyncTaskService;
	 
	/**
	 * 任务执行结果通知
	 * @author wechat:happybabby110
	 * @blog http://www.wlkankan.cn
	 */
	@Async
    public  void handleMsg(ChannelHandlerContext ctx, TransportMessage vo) {
        try {
        	TaskResultNoticeMessage req = vo.getContent().unpack(TaskResultNoticeMessage.class);
        	String  json = JsonFormat.printer().print(req);
        	log.debug(json);
         
        	//修改群id
        	asyncTaskService.updateChatRoomId(req);
        	
			asyncTaskService.msgSend2pc(String.valueOf(req.getWxId()), EnumMsgType.TaskResultNotice, req);
	  
			// 告诉客户端消息已收到
			MessageUtil.sendMsg(ctx, EnumMsgType.MsgReceivedAck, vo.getAccessToken(), vo.getId(), null);
        } catch (Exception e) {
            e.printStackTrace();
            MessageUtil.sendErrMsg(ctx, EnumErrorCode.InvalidParam,vo.getId(), Constant.ERROR_MSG_DECODFAIL);
        }
        
    }
}