package com.jubotech.framework.netty.handler.socket;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import com.google.protobuf.util.JsonFormat;
import com.jubotech.business.web.domain.WxAccountInfo;
import com.jubotech.business.web.service.WxAccountService;
import com.jubotech.framework.netty.async.AsyncTaskService;
import com.jubotech.framework.netty.common.Constant;
import com.jubotech.framework.netty.handler.MessageHandler;
import com.jubotech.framework.netty.utils.MessageUtil;

import Im.Scrm.Ww.Proto.WTransport.EnumErrorCode;
import Im.Scrm.Ww.Proto.WTransport.EnumMsgType;
import Im.Scrm.Ww.Proto.WTransport.TransportMessage;
import Im.Scrm.Ww.Proto.WwOfflineNotice.WwOfflineNoticeMessage;
import io.netty.channel.ChannelHandlerContext;
import lombok.extern.slf4j.Slf4j;

@Service
@Slf4j
public class WwOfflineNoticeHandler implements MessageHandler {
	@Autowired
	private WxAccountService weChatAccountService;
 
	@Autowired
	private AsyncTaskService asyncTaskService;

	/**
	 * 企业微信下线通知
	 * 
	 * @author wechat:happybabby110
	 * @blog http://www.wlkankan.cn
	 */
	@Async
	public void handleMsg(ChannelHandlerContext ctx, TransportMessage vo) {
		try {
			WwOfflineNoticeMessage req = vo.getContent().unpack(WwOfflineNoticeMessage.class);
			log.debug(JsonFormat.printer().print(req));
			if (null != req) {
				// 把消息转发给pc端
				WxAccountInfo account = weChatAccountService
						.findWeChatAccountInfoByWeChatId(String.valueOf(req.getWxId()));
				if (null != account) {
					account.setIsonline(1);// 下线
					weChatAccountService.update(account);

					asyncTaskService.msgSend2pc(String.valueOf(req.getWxId()), EnumMsgType.WwOfflineNotice, req);
				}

				// 3、告诉客户端消息已收到
				MessageUtil.sendMsg(ctx, EnumMsgType.MsgReceivedAck, vo.getAccessToken(), vo.getId(), null);
			} else {
				MessageUtil.sendErrMsg(ctx, EnumErrorCode.InvalidParam, vo.getId(), Constant.ERROR_MSG_ILLEGALDEVICE);
			}

		} catch (Exception e) {
			e.printStackTrace();
			MessageUtil.sendErrMsg(ctx, EnumErrorCode.InvalidParam, vo.getId(), Constant.ERROR_MSG_DECODFAIL);
		}
	}

}