package com.jubotech.framework.netty.handler.socket;

import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import com.google.protobuf.util.JsonFormat;
import com.jubotech.business.web.domain.WxAccountInfo;
import com.jubotech.business.web.service.WxAccountService;
import com.jubotech.framework.netty.async.AsyncTaskService;
import com.jubotech.framework.netty.handler.MessageHandler;
import com.jubotech.framework.netty.utils.MessageUtil;
import com.jubotech.framework.netty.utils.NettyConnectionUtil;
import com.jubotech.framework.util.EmojiFilter;

import Im.Scrm.Ww.Proto.WTransport.EnumErrorCode;
import Im.Scrm.Ww.Proto.WTransport.EnumMsgType;
import Im.Scrm.Ww.Proto.WTransport.TransportMessage;
import Im.Scrm.Ww.Proto.WwOnlineNotice.WwOnlineNoticeMessage;
import io.netty.channel.ChannelHandlerContext;
import lombok.extern.slf4j.Slf4j;

@Service
@Slf4j
public class WwOnlineNoticeHandler implements MessageHandler{
	@Autowired
	private WxAccountService weChatAccountService;
	 
	@Autowired
	private AsyncTaskService asyncTaskService;
	
	@Autowired
	private NettyConnectionUtil nettyConnectionUtil;
	 
	/** 
	 * 企业微信上线通知 
	 * @author wechat:happybabby110
	 * @blog http://www.wlkankan.cn
	 */
	@Async
    public  void handleMsg(ChannelHandlerContext ctx, TransportMessage vo) {
        try {
        	WwOnlineNoticeMessage req = vo.getContent().unpack(WwOnlineNoticeMessage.class);
        	log.debug(JsonFormat.printer().print(req));
        	//1、校验用户信息
        	if(null != req){
	        	//2、存储微信全局id 与通道
        		nettyConnectionUtil.registerUserid(String.valueOf(req.getWxId()),ctx);
	        	  
	    		WxAccountInfo  accountInfo =  weChatAccountService.findWeChatAccountInfoByDeviceid(req.getIMEI());
        		if(null != accountInfo){
    				//做个保护，如果当前微信号在其他设备上登陆过，就把之前那条记录删除
    				if(!StringUtils.isBlank(req.getIMEI())){
    					List<WxAccountInfo> list= weChatAccountService.findWeChatAccountInfoByWeChatIdNotEqualsDeviceid(String.valueOf(req.getWxId()), req.getIMEI());
            			if(null != list && list.size()>0){
            				for(int i=0;i<list.size();i++){
            					WxAccountInfo info = list.get(i);
            					weChatAccountService.delete(info.getId());
            				}
            			} 
    				}
        			//设置新的参数
        			setAccountInfo(req, accountInfo);
        			 
        			//改为上线状态
        			accountInfo.setIsonline(0);//上线
    				weChatAccountService.update(accountInfo);
    				//3、告诉客户端消息已收到
            		MessageUtil.sendMsg(ctx, EnumMsgType.MsgReceivedAck, vo.getAccessToken(), vo.getId(), null);
            		
        		}
        		
        		if(null != accountInfo){
    				asyncTaskService.msgSend2pc(String.valueOf(req.getWxId()), EnumMsgType.WwOnlineNotice, req);
        		}
        		 
        	} 
         
        } catch (Exception e) {
            e.printStackTrace();
            MessageUtil.sendErrMsg(ctx, EnumErrorCode.InvalidParam,vo.getId(), e.getMessage());
        }
    }
	private void setAccountInfo(WwOnlineNoticeMessage req, WxAccountInfo accountInfo) {
		String name = EmojiFilter.filterEmoji(req.getName());//过滤emoji
		accountInfo.setWxid(String.valueOf(req.getWxId()));
		accountInfo.setName(name);
		accountInfo.setAlias(req.getAlias());
		accountInfo.setGender(req.getGenderValue());
		accountInfo.setAvatar(req.getAvatar());
		accountInfo.setJob(req.getJob());
		accountInfo.setPhone(req.getPhone());
		accountInfo.setCorpid(String.valueOf(req.getCorpId()));
		weChatAccountService.update(accountInfo);
	}
}