package com.jubotech.framework.netty.processor;

import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;

import com.alibaba.fastjson.JSONObject;
import com.googlecode.protobuf.format.JsonFormat;
import com.jubotech.framework.netty.handler.JsonMessageHandler;
import com.jubotech.framework.netty.utils.MessageUtil;
import com.jubotech.framework.util.StringUtil;

import Im.Scrm.Ww.Proto.WTransport.EnumErrorCode;
import Im.Scrm.Ww.Proto.WTransport.TransportMessage;
import io.netty.channel.ChannelHandlerContext;
import io.netty.handler.codec.http.websocketx.TextWebSocketFrame;
import lombok.extern.slf4j.Slf4j;

/**
 * 消息处理分发器
 */
@Service
@Slf4j
public class WebSocketMessageProcessor {

	@Autowired
	private Map<String, JsonMessageHandler> handlers;

	public void handler(ChannelHandlerContext ctx, TextWebSocketFrame msg) {
		String text = msg.text();
		if (!StringUtils.isEmpty(text)) {
			try {
				JSONObject jsonObject = JSONObject.parseObject(text);
				Object objMsgType = jsonObject.get("MsgType");

				if (null == objMsgType) {
					log.error("MsgType消息类型传入错误！");
					MessageUtil.sendJsonErrMsg(ctx, EnumErrorCode.InvalidParam, "MsgType消息类型传入错误");
					return;
				}

				String contentJsonStr = jsonObject.getString("Content");
				if (StringUtils.isEmpty(contentJsonStr)) {
					log.error("Content消息类型传入错误！");
					MessageUtil.sendJsonErrMsg(ctx, EnumErrorCode.InvalidParam, "Content消息类型传入错误");
					return;
				}

				TransportMessage.Builder builder = TransportMessage.newBuilder();
				try {
					String jsonFormat = jsonObject.toJSONString();
					JsonFormat.merge(jsonFormat, builder);
				} catch (Exception e) {
					log.error("websocket传入json字符串转换proto失败！传入参数===" + jsonObject);
				}
				TransportMessage vo = builder.build();

				String msgtype = StringUtil.toLowerCaseFirstOne(objMsgType.toString() + "WebsocketHandler");
				log.debug("websocket:" + msgtype);
				if (handlers.containsKey(msgtype)) {
					handlers.get(msgtype).handleMsg(ctx, vo, contentJsonStr);
				} else {
					log.error("消息类型传入错误！" + msgtype);
				}

			} catch (Exception e) {
				log.debug("参数传入错误！");
				MessageUtil.sendJsonErrMsg(ctx, EnumErrorCode.InvalidParam, "参数传入错误");
			}
		}
		text = null;// 清空一下
	}

}
